@@ -1,4 +1,4 @@
-# Info command.
+"""Fetch and edit raster dataset metadata from the command line."""
 
 import json
 import logging
@@ -9,6 +9,100 @@ import click
 import rasterio
 import rasterio.crs
 from rasterio.rio.cli import cli, bidx_opt, file_in_arg, masked_opt
+from rasterio.transform import guard_transform
+
+
+@cli.command('edit-info', short_help="Edit dataset metadata.")
+@file_in_arg
+@click.option('--nodata', type=float, default=None,
+              help="New nodata value")
+@click.option('--crs', help="New coordinate reference system")
+@click.option('--transform', help="New affine transform matrix")
+@click.option('--tag', 'tags', multiple=True, metavar='KEY=VAL',
+              help="New tag.")
+@click.pass_context
+def edit(ctx, input, nodata, crs, transform, tags):
+    """Edit a dataset's metadata: coordinate reference system, affine
+    transformation matrix, nodata value, and tags.
+
+    CRS may be either a PROJ.4 or EPSG:nnnn string, or a JSON-encoded
+    PROJ.4 object.
+
+    Transforms are either JSON-encoded Affine objects (preferred) like
+
+      [300.038, 0.0, 101985.0, 0.0, -300.042, 2826915.0]
+
+    or JSON-encoded GDAL geotransform arrays like
+
+      [101985.0, 300.038, 0.0, 2826915.0, 0.0, -300.042]
+    """
+    import numpy as np
+
+    verbosity = (ctx.obj and ctx.obj.get('verbosity')) or 1
+    logger = logging.getLogger('rio')
+
+    def in_dtype_range(value, dtype):
+        infos = {'c': np.finfo, 'f': np.finfo, 'i': np.iinfo,
+                 'u': np.iinfo}
+        rng = infos[np.dtype(dtype).kind](dtype)
+        return rng.min <= value <= rng.max
+
+    with rasterio.drivers(CPL_DEBUG=(verbosity > 2)) as env:
+        with rasterio.open(input, 'r+') as dst:
+
+            # Update nodata.
+            if nodata is not None:
+
+                dtype = dst.dtypes[0]
+                if not in_dtype_range(nodata, dtype):
+                    raise click.BadParameter(
+                        "outside the range of the file's "
+                        "data type (%s)." % dtype,
+                        param=nodata, param_hint='nodata')
+
+                dst.nodata = nodata
+
+            # Update CRS. Value might be a PROJ.4 string or a JSON
+            # encoded dict.
+            if crs:
+                new_crs = crs.strip()
+                try:
+                    new_crs = json.loads(crs)
+                except ValueError:
+                    pass
+
+                if not (rasterio.crs.is_geographic_crs(new_crs) or 
+                        rasterio.crs.is_projected_crs(new_crs)):
+                    raise click.BadParameter(
+                        "'%s' is not a recognized CRS." % crs,
+                        param=crs, param_hint='crs')
+
+                dst.crs = new_crs
+
+            # Update transform. Value might be a JSON encoded
+            # Affine object or a GDAL geotransform array.
+            if transform:
+                try:
+                    transform_obj = json.loads(transform)
+                except ValueError:
+                    raise click.BadParameter(
+                        "'%s' is not a JSON array." % transform,
+                        param=transform, param_hint='transform')
+
+                try:
+                    transform_obj = guard_transform(transform_obj)
+                except:
+                    raise click.BadParameter(
+                        "'%s' is not recognized as an Affine or GDAL "
+                        "geotransform array." % transform,
+                        param=transform, param_hint='transform')
+
+                dst.transform = transform_obj
+
+            # Update tags.
+            if tags:
+                tags = dict(p.split('=') for p in tags)
+                dst.update_tags(**tags)
 
 
 @cli.command(short_help="Print information about the rio environment.")
@@ -85,8 +179,8 @@ def info(ctx, input, aspect, indent, namespace, meta_member, verbose, bidx,
         with rasterio.drivers(CPL_DEBUG=(verbosity > 2)):
             with rasterio.open(input, mode) as src:
                 info = src.meta
+                info['transform'] = info['affine'][:6]
                 del info['affine']
-                del info['transform']
                 info['shape'] = info['height'], info['width']
                 info['bounds'] = src.bounds
                 proj4 = rasterio.crs.to_string(src.crs)
@@ -116,9 +210,8 @@ def info(ctx, input, aspect, indent, namespace, meta_member, verbose, bidx,
                     else:
                         click.echo(json.dumps(info, indent=indent))
                 elif aspect == 'tags':
-                    click.echo(json.dumps(src.tags(ns=namespace), 
+                    click.echo(json.dumps(src.tags(ns=namespace),
                                             indent=indent))
-        sys.exit(0)
     except Exception:
-        logger.exception("Failed. Exception caught")
-        sys.exit(1)
+        logger.exception("Exception caught during processing")
+        raise click.Abort()
