@@ -1,8 +1,11 @@
 # main: loader of all the command entry points.
 
+import sys
+import traceback
+
 from pkg_resources import iter_entry_points
 
-from rasterio.rio.cli import cli
+from rasterio.rio.cli import BrokenCommand, cli
 
 
 # Find and load all entry points in the rasterio.rio_commands group.
@@ -19,4 +22,11 @@ from rasterio.rio.cli import cli
 #       ...
 
 for entry_point in iter_entry_points('rasterio.rio_commands'):
-    entry_point.load()
+    try:
+        entry_point.load()
+    except Exception:
+        # Catch this so a busted plugin doesn't take down the CLI.
+        # Handled by registering a dummy command that does nothing
+        # other than explain the error.
+        cli.add_command(
+            BrokenCommand(entry_point.name))
